@@ -5,7 +5,9 @@ use serde::{Deserialize, Serialize};
 use std::convert::TryFrom;
 
 /// Direction in degrees
-#[derive(Into, Debug, PartialEq, Copy, Clone, PartialOrd, Serialize, Deserialize, Display, Default)]
+#[derive(
+    Into, Debug, PartialEq, Copy, Clone, PartialOrd, Serialize, Deserialize, Display, Default,
+)]
 #[serde(into = "i32", try_from = "i32")]
 pub struct TimeZone(i32);
 
